@@ -1,20 +1,5 @@
 package SQL::Dialects::AnyData;
 
-
-=head1 NAME
-
- SQL::Dialects::AnyData -- AnyData config file for SQL::Parse
-
-=head1 SYNOPSIS
-
-  see SQL::Parse, SQL::Squish
-
-=head1 DESCRIPTION
-
- The makemaker police say i gotta have one of these
-
-=cut
-
 sub get_config {
 return <<EOC;
 [VALID COMMANDS]
